
.. xoutil documentation master file, created by
   sphinx-quickstart on Fri Jun 15 14:31:00 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to xoutil's documentation!
==================================

.. automodule:: xoutil
   :members:


What's new in this version
--------------------------

.. include:: history/_changes-1.5.4.rst


And from version 1.5.0
~~~~~~~~~~~~~~~~~~~~~~

.. include:: history/_changes-1.5.3.rst
.. include:: history/_changes-1.5.2.rst
.. include:: history/_changes-1.5.1.rst
.. include:: history/_changes-1.5.0.rst


Contents:
---------

.. toctree::
   :maxdepth: 2
   :glob:

   xoutil/toplevel
   xoutil/*
   xoutil/**
   others
   HISTORY
   CONTRIBUTING
   CONTRIBUTORS
   LICENSE


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
